Module extensions

Module extensions 

The embedded Substrait core extension YAML files.

The contents of this module are auto-generated by build.rs and kept in sync with the packaged extension files.

Constants

EXTENSION_TYPES
Included source of the extension_types extension YAML file.
FUNCTIONS_AGGREGATE_APPROX
Included source of the functions_aggregate_approx extension YAML file.
FUNCTIONS_AGGREGATE_DECIMAL_OUTPUT
Included source of the functions_aggregate_decimal_output extension YAML file.
FUNCTIONS_AGGREGATE_GENERIC
Included source of the functions_aggregate_generic extension YAML file.
FUNCTIONS_ARITHMETIC
Included source of the functions_arithmetic extension YAML file.
FUNCTIONS_ARITHMETIC_DECIMAL
Included source of the functions_arithmetic_decimal extension YAML file.
FUNCTIONS_BOOLEAN
Included source of the functions_boolean extension YAML file.
FUNCTIONS_COMPARISON
Included source of the functions_comparison extension YAML file.
FUNCTIONS_DATETIME
Included source of the functions_datetime extension YAML file.
FUNCTIONS_GEOMETRY
Included source of the functions_geometry extension YAML file.
FUNCTIONS_LIST
Included source of the functions_list extension YAML file.
FUNCTIONS_LOGARITHMIC
Included source of the functions_logarithmic extension YAML file.
FUNCTIONS_ROUNDING
Included source of the functions_rounding extension YAML file.
FUNCTIONS_ROUNDING_DECIMAL
Included source of the functions_rounding_decimal extension YAML file.
FUNCTIONS_SET
Included source of the functions_set extension YAML file.
FUNCTIONS_STRING
Included source of the functions_string extension YAML file.
TYPE_VARIATIONS
Included source of the type_variations extension YAML file.

Statics

EXTENSIONS
Map with the Substrait core extensions, keyed by file stem (e.g. functions_arithmetic).
SIMPLE_EXTENSIONS
All Substrait core extensions as (urn, raw YAML source) pairs, where urn is the value of the extension file’s top-level urn field.