DialectSupportedExecutionBehavior

Struct DialectSupportedExecutionBehavior 

pub struct DialectSupportedExecutionBehavior {
    pub supported_variable_evaluation_mode: Option<Vec<DialectSupportedExecutionBehaviorSupportedVariableEvaluationModeItem>>,
}
DialectSupportedExecutionBehavior

JSON schema
{
 "type": "object",
 "properties": {
   "supported_variable_evaluation_mode": {
     "description": "Supported execution context variable evaluation modes: * PER_PLAN: Variables are evaluated once per Substrait plan\n  execution. All records in a single plan execution will see the\n  same values for execution context variables like `current_date`\n  and `current_timestamp`.\n* PER_RECORD: Variables are evaluated once per record during\n  execution. Each record may see different values for execution\n  context variables if the execution context changes between records.\n",
     "type": "array",
     "items": {
       "oneOf": [
         {
           "enum": [
             "PER_PLAN",
             "PER_RECORD"
           ]
         }
       ]
     },
     "uniqueItems": true
   }
 },
 "additionalProperties": false
}

Fields

supported_variable_evaluation_mode: Option<Vec<DialectSupportedExecutionBehaviorSupportedVariableEvaluationModeItem>>

Supported execution context variable evaluation modes: * PER_PLAN: Variables are evaluated once per Substrait plan execution. All records in a single plan execution will see the same values for execution context variables like current_date and current_timestamp.

  • PER_RECORD: Variables are evaluated once per record during execution. Each record may see different values for execution context variables if the execution context changes between records.

Implementations